@@ -13,6 +13,7 @@
 
 (texmacs-module (generic generic-menu)
   (:use (utils edit variants)
+	(utils edit selections)
 	(generic generic-edit)
 	(generic format-edit)
 	(generic format-geometry-edit)
@@ -27,10 +28,15 @@
   (variants-of (tree-label t)))
 
 (tm-define (focus-tag-name l)
-  (if (symbol-unnumbered? l)
-      (focus-tag-name (symbol-drop-right l 1))
-      (with r (upcase-first (tree-name (tree l)))
-        (string-replace r "-" " "))))
+  (let* ((s (symbol->string l))
+         (th (member->theme s)))
+    (if th
+        (with ns (string-drop s (+ (string-length th) 1))
+          (focus-tag-name (string->symbol ns)))
+        (if (symbol-unnumbered? l)
+            (focus-tag-name (symbol-drop-right l 1))
+            (with r (upcase-first (tree-name (tree l)))
+              (string-replace r "-" " "))))))
 
 (tm-menu (focus-variant-menu t)
   (for (v (focus-variants-of t))
@@ -149,6 +155,8 @@
             (pick-background "" (setter answer))
             ---
             ("Palette" (interactive-color setter '()))
+            ("Pattern" (open-pattern-selector setter "1cm"))
+            ("Picture" (open-background-picture-selector setter))
             ("Other" (interactive setter
                        (list (upcase-first name) "color" in*)))))))
 
@@ -219,15 +227,49 @@
 (tm-menu (focus-parameter-menu-item l)
   (:require (and (tree-label-parameter? (string->symbol l))
                  (== (tree-label-type (string->symbol l)) "color")))
+  (-> (eval (focus-tag-name (string->symbol l)))
+      (with setter (lambda (col) (init-env-tree l col))
+        ((check "Default" "*" (test-default? l)) (init-default l))
+        ---
+        (pick-background "" (setter answer))
+        ---
+        (if (in? l (list "locus-color" "visited-color"))
+            ((check "Preserve" "*" (test-init? l "preserve"))
+             (set-init-env l "preserve")))
+        ("Palette" (interactive-color setter '()))
+        ("Pattern" (open-pattern-selector setter "1cm"))
+        ("Picture" (open-background-picture-selector setter))
+        ("Other" (init-interactive-env l)))))
+
+(tm-menu (focus-parameter-menu-item l)
+  (:require (and (tree-label-parameter? (string->symbol l))
+                 ;;(== (tree-label-type (string->symbol l)) "font")
+                 (string-ends? l "-font")))
   (-> (eval (focus-tag-name (string->symbol l)))
       ((check "Default" "*" (test-default? l)) (init-default l))
       ---
-      (pick-background "" (init-env-tree l answer))
+      ((check "Roman" "*" (test-init? l "roman")) (init-env l "roman"))
+      ((check "Stix" "*" (test-init? l "stix")) (init-env l "stix"))
+      ((check "Bonum" "*" (test-init? l "bonum")) (init-env l "bonum"))
+      ((check "Pagella" "*" (test-init? l "pagella")) (init-env l "pagella"))
+      ((check "Schola" "*" (test-init? l "schola")) (init-env l "schola"))
+      ((check "Termes" "*" (test-init? l "termes")) (init-env l "termes"))
+      ---
+      (with prefix (string-drop-right l 4)
+        ("Other" (open-document-other-font-selector prefix)))))
+
+(tm-menu (focus-parameter-menu-item l)
+  (:require (and (tree-label-parameter? (string->symbol l))
+                 (== (tree-label-type (string->symbol l)) "font-size")))
+  (-> (eval (focus-tag-name (string->symbol l)))
+      ((check "Default" "*" (test-default? l)) (init-default l))
+      ---
+      ((check "Small" "*" (test-init? l "0.841")) (init-env l "0.841"))
+      ((check "Normal" "*" (test-init? l "1")) (init-env l "1"))
+      ((check "Large" "*" (test-init? l "1.189")) (init-env l "1.189"))
+      ((check "Very large" "*" (test-init? l "1.414")) (init-env l "1.414"))
+      ((check "Huge" "*" (test-init? l "1.682")) (init-env l "1.682"))
       ---
-      (if (in? l (list "locus-color" "visited-color"))
-          ((check "Preserve" "*" (test-init? l "preserve"))
-           (set-init-env l "preserve")))
-      ("Palette" (interactive-color (lambda (col) (init-env l col)) '()))
       ("Other" (init-interactive-env l))))
 
 (tm-menu (focus-parameter-menu-item l)
@@ -236,7 +278,8 @@
     (-> (eval (focus-tag-name (string->symbol l)))
         (dynamic (init-env-menu l cs)))))
 
-(tm-define (parameter-show-in-menu? l) #t)
+(tm-define (parameter-show-in-menu? l)
+  (not (member->theme l)))
 
 (tm-menu (focus-parameters-menu t)
   (with ps (list-filter (search-tag-parameters t) parameter-show-in-menu?)
@@ -247,6 +290,21 @@
         (if (tree-label-extension? (tree-label t))
             ---))))
 
+(tm-menu (focus-theme-parameters-submenu th)
+  (with mems (theme->members th)
+    (for (mem mems)
+      (with var (string-append th "-" mem)
+        (dynamic (focus-parameter-menu-item var))))))
+
+(tm-menu (focus-theme-parameters-menu t)
+  (with ths (search-tag-themes t)
+    (if (nnull? ths)
+        (group "Theme parameters")
+        (for (th ths)
+          (-> (eval th)
+              (dynamic (focus-theme-parameters-submenu th))))
+        ---)))
+
 (tm-define (parameter-show-in-menu? l)
   (:require (in? l (list "the-label" "auto-nr" "current-part" "language"
                          "page-nr" "page-the-page" "prog-language"
@@ -301,8 +359,11 @@
 (tm-menu (focus-preferences-menu t)
   (dynamic (focus-style-options-menu t))
   (dynamic (focus-parameters-menu t))
+  (dynamic (focus-theme-parameters-menu t))
   (dynamic (focus-tag-edit-menu (tree-label t))))
 
+(tm-menu (focus-theme-menu t))
+
 (tm-menu (focus-tag-menu t)
   (with l (focus-variants-of t)
     (assuming (<= (length l) 1)
@@ -317,6 +378,9 @@
   (assuming (focus-has-preferences? t)
     (-> "Preferences"
         (dynamic (focus-preferences-menu t))))
+  (assuming (focus-has-theme? t)
+    (-> "Rendering"
+        (dynamic (focus-theme-menu t))))
   ("Describe" (focus-help))
   (assuming (focus-can-search? t)
     ("Search in database" (focus-open-search-tool t)))
@@ -397,7 +461,7 @@
             (numbered-numbered? (focus-tree)))
      (numbered-toggle (focus-tree))))
   (assuming (alternate-first? t)
-    ((check (balloon (icon "tm_alternate_first.xpm")
+    ((check (balloon (icon (eval (alternate-first-icon t)))
                      (eval (alternate-second-name t))) "v" #f)
      (alternate-toggle (focus-tree))))
   (assuming (alternate-second? t)
@@ -438,6 +502,9 @@
   (assuming (focus-has-preferences? t)
     (=> (balloon (icon "tm_focus_prefs.xpm") "Preferences for tag")
 	(dynamic (focus-preferences-menu t))))
+  (assuming (focus-has-theme? t)
+    (=> (balloon (icon "tm_theme.xpm") "Rendering options for tag")
+        (dynamic (focus-theme-menu t))))
   ((balloon (icon "tm_focus_help.xpm") "Describe tag")
    (focus-help))
   (assuming (focus-can-search? t)
@@ -532,6 +599,8 @@
       (pick-background "" (setter answer))
       ---
       ("Palette" (interactive-color setter '()))
+      ("Pattern" (open-pattern-selector setter "1cm"))
+      ("Picture" (open-background-picture-selector setter))
       ("Other" (interactive setter (list name "string" (get-env var))))))
 
 (tm-menu (focus-extra-menu t)
@@ -561,6 +630,8 @@
       (pick-background "" (setter answer))
       ---
       ("Palette" (interactive-color setter '()))
+      ("Pattern" (open-pattern-selector setter "1cm"))
+      ("Picture" (open-background-picture-selector setter))
       ("Other" (interactive setter (list name "string" (get-env var))))))
 
 (tm-menu (focus-extra-icons t)
