@@ -41,33 +41,43 @@
   ("simple ""Simplified menus")
   ("detailed" "Detailed menus"))
 
+(define-preference-names "buffer management"
+  ("separate" "Documents in separate windows")
+  ("shared" "Multiple documents share window"))
+
 (tm-widget (general-preferences-widget)
   (aligned
     (item (text "Look and feel:")
       (enum (set-pretty-preference "look and feel" answer)
             '("Default" "Emacs" "Gnome" "KDE" "Mac OS" "Windows")
             (get-pretty-preference "look and feel")
-            "18em"))
+            "21em"))
     (item (text "User interface language:")
       (enum (set-pretty-preference "language" answer)
             (map upcase-first supported-languages)
             (get-pretty-preference "language")
-            "18em"))
+            "21em"))
     (item (text "Complex actions:")
       (enum (set-pretty-preference "complex actions" answer)
             '("Through the menus" "Through popup windows")
             (get-pretty-preference "complex actions")
-            "18em"))
+            "21em"))
     (item (text "Interactive questions:")
       (enum (set-pretty-preference "interactive questions" answer)
             '("On the footer" "In popup windows")
             (get-pretty-preference "interactive questions")
-            "18em"))
+            "21em"))
     (item (text "Details in menus:")
       (enum (set-pretty-preference "detailed menus" answer)
             '("Simplified menus" "Detailed menus")
             (get-pretty-preference "detailed menus")
-            "18em"))))
+            "21em"))
+    (item (text "Buffer management:")
+      (enum (set-pretty-preference "buffer management" answer)
+            '("Documents in separate windows"
+              "Multiple documents share window")
+            (get-pretty-preference "buffer management")
+            "21em"))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Keyboard preferences
@@ -452,6 +462,12 @@
             "5em"))))
 
 ;; Pdf ----------
+(define-preference-names "texmacs->pdf:version"
+  ("Default" "default")
+  ("1.4" "1.4")
+  ("1.5" "1.5")
+  ("1.6" "1.6")
+  ("1.7" "1.7"))
 
 (tm-widget (pdf-preferences-widget)
   ===
@@ -466,13 +482,20 @@
       (meti (hlist // (text "Produce Postscript using native export filter"))
 	(toggle (set-boolean-preference "native postscript" answer)
 		(get-boolean-preference "native postscript"))))
-    (meti (hlist // (text "Expand beamer slides"))
+   (meti (hlist // (text "Expand beamer slides"))
       (toggle (set-boolean-preference "texmacs->pdf:expand slides" answer)
-	      (get-boolean-preference "texmacs->pdf:expand slides")))
+	      (get-boolean-preference "texmacs->pdf:expand slides"))))
     (assuming (supports-native-pdf?)
-      (meti (hlist // (text "Check exported Pdf files for correctness"))
+      (aligned (meti (hlist // (text "Distill encapsulated Pdf files"))
+	(toggle (set-boolean-preference "texmacs->pdf:distill inclusion" answer)
+		(get-boolean-preference "texmacs->pdf:distill inclusion"))))
+      (aligned (meti (hlist // (text "Check exported Pdf files for correctness"))
 	(toggle (set-boolean-preference "texmacs->pdf:check" answer)
-		(get-boolean-preference "texmacs->pdf:check"))))))
+		(get-boolean-preference "texmacs->pdf:check"))))
+      (aligned (item (text "Pdf version number:")
+        (enum (set-preference "texmacs->pdf:version" answer)
+	      '("default" "1.4" "1.5" "1.6" "1.7")
+	      (get-preference "texmacs->pdf:version") "8em")))))
 
 ;; Images ----------
 
@@ -559,7 +582,7 @@
 (define (updater-last-check-formatted)
   "Time since last update check formatted for use in the preferences dialog"
   (with c (updater-last-check)
-    (if (== c 0) 
+    (if (<= c 0) 
         "Never"
         (with h (ceiling (/ (- (current-time) c) 3600))
           (cond ((< h 24) (replace "Less than %1 hour(s) ago" h))
@@ -626,7 +649,10 @@
                 (get-boolean-preference "advanced font customization")))
       (meti (hlist // (text "New style page breaking"))
         (toggle (set-boolean-preference "new style page breaking" answer)
-                (get-boolean-preference "new style page breaking"))))
+                (get-boolean-preference "new style page breaking")))
+      (meti (hlist // (text "Enable pattern effects"))
+        (toggle (set-boolean-preference "pattern effects" answer)
+                (get-boolean-preference "pattern effects"))))
     /// ///
     (vlist
       (aligned
@@ -643,6 +669,9 @@
         (meti (hlist // (text "Program bracket selections"))
           (toggle (set-boolean-preference "prog:select brackets" answer)
                   (get-boolean-preference "prog:select brackets")))
+        (meti (hlist // (text "Case-insensitive search"))
+          (toggle (set-boolean-preference "case-insensitive-match" answer)
+                  (get-boolean-preference "case-insensitive-match")))
         (assuming (qt-gui?)  ; TODO: recode the dialogue in scheme
           (meti (hlist // (text "Use print dialogue"))
             (toggle (set-boolean-preference "gui:print dialogue" answer)
