@@ -152,9 +152,9 @@
       ---)
   ("Exercise" (make 'exercise))
   ("Problem" (make 'problem))
-  ("Solution" (make 'solution))
   ("Question" (make 'question))
-  ("Answer" (make 'answer)))
+  ("Solution" (make 'solution*))
+  ("Answer" (make 'answer*)))
 
 (menu-bind prominent-menu
   ("Quote" (make 'quote-env))
@@ -164,9 +164,9 @@
   ("Indent" (make 'indent))
   ("Jump in" (make 'jump-in))
   ---
-  ("Centered" (make 'center))
-  ("Left aligned" (make 'left-aligned))
-  ("Right aligned" (make 'right-aligned))
+  ("Centered" (make 'padded-center))
+  ("Left aligned" (make 'padded-left-aligned))
+  ("Right aligned" (make 'padded-right-aligned))
   (with s (get-env "par-par-sep")
     (assuming (and (not (string-ends? s "fns"))
                    (not (string-starts? s "0fn")))
@@ -506,6 +506,8 @@
       ---
       (link lists-menu)))
 
+(menu-bind text-extra-menu)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Text menus for inserting inline content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -525,6 +527,7 @@
 
 (menu-bind text-menu
   (link text-block-menu)
+  (link text-extra-menu)
   ---
   (link text-inline-menu)
   ---
@@ -581,6 +584,8 @@
                    "Insert automatically generated content")
           (link automatic-menu))))
 
+(menu-bind text-extra-icons)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Icons for modifying text properties
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -641,14 +646,15 @@
   ;;("Goedenmiddag" (display* "Hi there\n"))
   ;;(mini #t (input (display* answer "\n") "string" '("Hello" "Bonjour") "0.5w"))
   (link text-block-icons)
+  (link text-extra-icons)
   (if (style-has? "std-markup-dtd")
       /)
   (link text-inline-icons)
   (if (in-manual?) (link tmdoc-icons))
   (link texmacs-insert-icons)
   (if (and (in-presentation?) (not (visible-icon-bar? 0)))
-    /
-    (link dynamic-icons)))
+      /
+      (link dynamic-icons)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menus for entering title information
